==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectArrayNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectArrayNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5e0dc3ae69d7dd87 soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fget$57d8701654e8e825(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fmultiNewArray$c00ab3350b9e32dd(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fnewArray$d248df5da5ae6af0(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fset$5029c4b17d6f842c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$v$f00ef4b75fa08179(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectArrayNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectArrayNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5e0dc3ae69d7dd87 soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fget$57d8701654e8e825(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fmultiNewArray$c00ab3350b9e32dd(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fnewArray$d248df5da5ae6af0(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$java__5flang__5freflect__5fArray__5fset$5029c4b17d6f842c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$method$v$f00ef4b75fa08179(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectArrayNative_H_ */
